all.Indms<-function(){
     cat("\n")
     note_for_Indss_input()
     cat("\n")
     note_for_close_window()
     IndMSpar<-data.frame(subject=c(1,2),Gender=c(0),bw=c(0),Rit=c(0),D=c(0),tau=c(0),ts=c(0),c=c(0))
     IndMSpar<-edit(IndMSpar)
##     IndMSpar<-ymscheck(IndMSpar)
     cat("\n")
     Ind.ms(length(IndMSpar$subject),IndMSpar$c,IndMSpar$tau,IndMSpar$ts,IndMSpar$D,IndMSpar$bw,IndMSpar$Rit,IndMSpar$Gender)
     note_for_convergence_plots()
     note_for_plot()
     convergence_plots_con()
     note_for_Indss_output()
     show(samplesStats("*"))
     cat("\n") 
     C<-Indcpr(samplesStats("ka"),IndMSpar$D,IndMSpar$tau,IndMSpar$ts)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     output1<-coutput
     show(coutput)
     C<-Indcpr(samplesStats("ka"),IndMSpar$D,IndMSpar$tau,IndMSpar$tau)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output2<-coutput
     show(coutput)    
     cat("\n") 
     cal.again()
}